==> koRpus_0.04-27.tar.gz: koRpus/man/lex.div.num.Rd <==
\name{lex.div.num}
\alias{lex.div.num}
\title{Calculate lexical diversity}
\usage{
  lex.div.num(num.tokens, num.types,
    measure = c("TTR", "C", "R", "CTTR", "U", "S", "Maas"))
}
\arguments{
  \item{num.tokens}{Numeric, the number of tokens.}

  \item{num.types}{Numeric, the number of types.}

  \item{measure}{A character vector defining the measures
  to calculate.}
}
\value{
  An object of class \code{\link[koRpus]{kRp.TTR-class}}.
}
\description{
  This function is a stripped down version of
  \code{\link[koRpus:lex.div]{lex.div}}. It does not
  analyze text, but takes the numbers of tokens and types
  directly to calculate measures for which this information
  is sufficient: \itemize{ \item \code{"TTR"}{The classic
  \emph{Type-Token Ratio}} \item {\code{"C"}}{Herdan's
  \emph{C}} \item {\code{"R"}}{Guiraud's \emph{Root TTR}}
  \item {\code{"CTTR"}}{Carroll's \emph{Corrected TTR}}
  \item {\code{"U"}}{Dugast's \emph{Uber Index}} \item
  {\code{"S"}}{Summer's index} \item {\code{"Maas"}} {Maas'
  (\eqn{a^2})} } See \code{\link[koRpus:lex.div]{lex.div}}
  for further details on the formulae.
}
\examples{
lex.div.num(104, 43)
}
\references{
  Maas, H.-D., (1972). Über den Zusammenhang zwischen
  Wortschatzumfang und Länge eines Textes.
  \emph{Zeitschrift für Literaturwissenschaft und
  Linguistik}, 2(8), 73--96.

  Tweedie. F.J. & Baayen, R.H. (1998). How Variable May a
  Constant Be? Measures of Lexical Richness in Perspective.
  \emph{Computers and the Humanities}, 32(5), 323--352.
}
\seealso{
  \code{\link[koRpus:lex.div]{lex.div}}
}
\keyword{LD}

==> koRpus_0.04-40.tar.gz: koRpus/man/lex.div.num.Rd <==
\name{lex.div.num}
\alias{lex.div.num}
\title{Calculate lexical diversity}
\usage{
  lex.div.num(num.tokens, num.types,
    measure = c("TTR", "C", "R", "CTTR", "U", "S", "Maas"))
}
\arguments{
  \item{num.tokens}{Numeric, the number of tokens.}

  \item{num.types}{Numeric, the number of types.}

  \item{measure}{A character vector defining the measures
  to calculate.}
}
\value{
  An object of class \code{\link[koRpus]{kRp.TTR-class}}.
}
\description{
  This function is a stripped down version of
  \code{\link[koRpus:lex.div]{lex.div}}. It does not
  analyze text, but takes the numbers of tokens and types
  directly to calculate measures for which this information
  is sufficient: \itemize{ \item \code{"TTR"}{The classic
  \emph{Type-Token Ratio}} \item {\code{"C"}}{Herdan's
  \emph{C}} \item {\code{"R"}}{Guiraud's \emph{Root TTR}}
  \item {\code{"CTTR"}}{Carroll's \emph{Corrected TTR}}
  \item {\code{"U"}}{Dugast's \emph{Uber Index}} \item
  {\code{"S"}}{Summer's index} \item {\code{"Maas"}} {Maas'
  (\eqn{a^2})} } See \code{\link[koRpus:lex.div]{lex.div}}
  for further details on the formulae.
}
\examples{
lex.div.num(104, 43)
}
\references{
  Maas, H.-D., (1972). \"Uber den Zusammenhang zwischen
  Wortschatzumfang und L\"ange eines Textes.
  \emph{Zeitschrift f\"ur Literaturwissenschaft und
  Linguistik}, 2(8), 73--96.

  Tweedie. F.J. & Baayen, R.H. (1998). How Variable May a
  Constant Be? Measures of Lexical Richness in Perspective.
  \emph{Computers and the Humanities}, 32(5), 323--352.
}
\seealso{
  \code{\link[koRpus:lex.div]{lex.div}}
}
\keyword{LD}
